==> hyfo_1.4.2.tar.gz: hyfo/README.md <==
# hyfo
<!-- [![Travis-CI Build Status](https://travis-ci.org/Yuanchao-Xu/hyfo.svg?branch=master)](https://travis-ci.org/Yuanchao-Xu/hyfo) -->
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/hyfo)](https://cran.r-project.org/package=hyfo)

## Installation

Released version from CRAN, for beginners and normal users:

```R
install.packages("hyfo")
```

Development version from github, for experienced users and those who are interested in investigating:

```R
install.packages("devtools")
# You can ignore the line above, if you have already installed devtools
devtools::install_github("Yuanchao-Xu/hyfo")
```

**Official Website is [https://yuanchao-xu.github.io/hyfo](http://yuanchao-xu.github.io/hyfo)**

hyfo is an R package, initially designed for the European Project EUPORIAS, and cooperated with DHI Denmark, which was then extended to other uses in hydrology, hydraulics and climate.

This package mainly focuses on data process and visulization in hydrology and climate forecasting. Main function includes NetCDF file processing, data extraction, data downscaling, data resampling, gap filler of precipitation, bias correction of forecasting data, flexible time series plot, and spatial map generation. It is a good pre-processing and post-processing tool for hydrological and hydraulic modellers.

**If you feel hyfo is of a little help, please cite it as following:**

Xu, Yuanchao(2015). hyfo: Hydrology and Climate Forecasting R Package for Data Analysis and Visualization. Retrieved from http://yuanchao-xu.github.io/hyfo/

==> hyfo_1.4.6.tar.gz: hyfo/README.md <==
# hyfo
<!-- [![Travis-CI Build Status](https://travis-ci.org/Yuanchao-Xu/hyfo.svg?branch=master)](https://travis-ci.org/Yuanchao-Xu/hyfo) -->
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/hyfo)](https://cran.r-project.org/package=hyfo)

## Installation

Released version from CRAN, for beginners and normal users:

```R
install.packages("hyfo")
```

Development version from github, for experienced users and those who are interested in investigating:

```R
install.packages("devtools")
# You can ignore the line above, if you have already installed devtools
devtools::install_github("Yuanchao-Xu/hyfo")
```

**Official Website is [https://yuanchao-xu.github.io/hyfo/](https://yuanchao-xu.github.io/hyfo/)**

hyfo is an R package, initially designed for the European Project EUPORIAS, and cooperated with DHI Denmark, which was then extended to other uses in hydrology, hydraulics and climate.

This package mainly focuses on data process and visulization in hydrology and climate forecasting. Main function includes NetCDF file processing, data extraction, data downscaling, data resampling, gap filler of precipitation, bias correction of forecasting data, flexible time series plot, and spatial map generation. It is a good pre-processing and post-processing tool for hydrological and hydraulic modellers.

**If you feel hyfo is of a little help, please cite it as following:**

Xu, Yuanchao(2020). hyfo: Hydrology and Climate Forecasting R Package for Data Analysis and Visualization. Retrieved from http://yuanchao-xu.github.io/hyfo/
